#!/bin/bash
# Build config for build.sh
APP_NAME=bindwood
CHROME_PROVIDERS="content locale"
CLEAN_UP=1
ROOT_FILES="couchdb_env.sh"
ROOT_DIRS="defaults modules"
BEFORE_BUILD=
AFTER_BUILD=
